"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var visitor_1 = require("./visitor");
var antlr4 = require('antlr4');
function parseAst(options) {
    var input = options.input;
    var _a = getParserForLanguage(options.language), Lexer = _a.Lexer, Parser = _a.Parser, mainRule = _a.mainRule;
    var chars = new antlr4.InputStream(input);
    var lexer = new Lexer(chars);
    var tokens = new antlr4.CommonTokenStream(lexer);
    var parser = new Parser(tokens);
    //  parser.buildParseTrees = true;
    var tree = parser[mainRule]();
    if (tree.exception) {
        throw new Error('Parser exception: ' + tree.exception);
    }
    var visitor = new visitor_1.Visitor(options);
    tree.accept(visitor);
    return visitor_1.getVisitorResult();
}
exports.parseAst = parseAst;
function getParserForLanguage(language) {
    if (language === 'c') {
        return {
            Lexer: require('./grammar/c/CLexer').CLexer,
            Parser: require('./grammar/c/CParser').CParser,
            mainRule: 'compilationUnit'
        };
    }
    else if (language === 'golang') {
        return {
            Lexer: require('./grammar/golang/GolangLexer').GolangLexer,
            Parser: require('./grammar/golang/GolangParser').GolangParser,
            mainRule: 'sourceFile'
        };
    }
    else if (language === 'scala') {
        return {
            Lexer: require('./grammar/scala/ScalaLexer').ScalaLexer,
            Parser: require('./grammar/scala/ScalaParser').ScalaParser,
            mainRule: 'compilationUnit'
        };
    }
    else if (language === 'ruby') {
        return {
            Lexer: require('./grammar/ruby/RubyLexer').RubyLexer,
            Parser: require('./grammar/ruby/RubyParser').RubyParser,
            mainRule: 'prog'
        };
    }
    else {
        throw new Error('Language unknown: ' + language);
    }
}
//# sourceMappingURL=parseAst.js.map